# midi_synth
Display midi in jupyter notebook with good sound


## Get soundfont file

```
wget https://freepats.zenvoid.org/Piano/SalamanderGrandPiano/SalamanderGrandPiano-SF2-V3+20200602.tar.xz
tar Jxvf SalamanderGrandPiano-SF2-V3+20200602.tar.xz  
```

## Requirement

```
pip install pretty_midi
```


## License
1. `test.mid` comes from [Ever So Blue - Onthou](https://www.youtube.com/watch?v=YhXRyOl5pi0), and I don't own the copyright.
2. The soundfont file comes from [FreePats](https://freepats.zenvoid.org/Piano/acoustic-grand-piano.html), and again I don't own the copyright. The author is Alexander Holm, axeldenstore (at) gmail (dot) com, and the original License is Creative Commons Attribution 3.0 license.

